@@ -13,9 +13,14 @@ class pytorch_backend(object):
         self.name = 'pytorch'
         self.dtypemap = {
             'float': getattr(torch, kwargs.get('float', 'float32')),
-            'int': getattr(torch, kwargs.get('float', 'int32')),
+            'int': getattr(torch, kwargs.get('int', 'int32')),
             'bool': torch.bool,
         }
+        torch.set_default_dtype(self.dtypemap["float"])
+        self.float_precision = (
+            '32b' if self.dtypemap['float'] == torch.float32 else '64b'
+        )
+        self.int_precision = '32b' if self.dtypemap['int'] == torch.int32 else '64b'
 
     def clip(self, tensor_in, min_value, max_value):
         """
